@@ -7,7 +7,7 @@ require Carp;
 require Scalar::Util;
 use File::Spec ();
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 our $LEADING_SPACE  = qr/(?:\n [ ]*)?/x;
 our $TRAILING_SPACE = qr/(?:[ ]* \n)?/x;
@@ -21,10 +21,14 @@ our $END_OF_SECTION            = quotemeta '/';
 
 sub new {
     my $class = shift;
+    my (%params) = @_;
 
-    my $self = {@_};
+    my $self = {};
     bless $self, $class;
 
+    $self->{templates_path}            = $params{templates_path};
+    $self->{default_partial_extension} = $params{default_partial_extension};
+
     $self->set_templates_path('.')
       unless $self->templates_path;
 
@@ -322,6 +326,10 @@ sub _parse_partial {
     my $self = shift;
     my ($template, $context) = @_;
 
+    if (my $ext = $self->{default_partial_extension}) {
+        $template = "$template.$ext";
+    }
+
     my $content = $self->_slurp_template($template);
 
     return $self->_parse($content, $context);
@@ -554,6 +562,18 @@ Return path where templates are searched.
 
 Set base path under which templates are searched.
 
+=head2 C<default_partial_extension>
+
+If this option is set that the extension is automatically added to the partial
+filenames.
+
+  my $engine = Text::Caml->new(default_partial_extension => 'caml');
+
+  ---
+  {{#articles}}
+  {{>article_summary}} # article_summary.caml will be searched
+  {{/articles}}
+
 =head1 METHODS
 
 =head2 C<new>
